"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = ensureObjectOfRegExps;
const lodash_escaperegexp_1 = __importDefault(require("lodash.escaperegexp"));
/**
 * EnsureObjectOfRegExps.
 * @param object  - { [index: string]: string|RegExp }.
 * @param options - Object.
 * @param options.insensitive - String.
 * @returns - Record<string, string|RegExp>.
 */
function ensureObjectOfRegExps(object, options) {
    const { insensitive } = options;
    const toReturn = {};
    for (const [key, value] of Object.entries(object)) {
        if (value instanceof RegExp) {
            toReturn[key] = value;
        }
        else {
            toReturn[key] = new RegExp(`(^|\\.)${(0, lodash_escaperegexp_1.default)(value)}(\\.|$)`, insensitive);
        }
    }
    return toReturn;
}
//# sourceMappingURL=ensureObjectOfRegExps.js.map